        program fitfunc04
        implicit real*8(a-h,o-z)
        parameter(pi=3.141593)
        dimension pc(200),xma(110),xla(110),v(110),pa(110),xmub(365),
     &      vstage(13), r0(200),cmean(200),csiz(400),cdates(8),
     &	    slopes(8),xfish(8),sdmeans(8),sdsigs(8),jyears(8)   
        common /params/ basemort

c------------ years are 1979 and 1981-1987.        
	data cdates/130.4,106.9,128.1,143.1,147.4,138.2,117.75,146.9/
        data slopes/0.041,0.069,0.090,0.059,0.016,0.091,0.091,0.01/
        data sdmeans/82.20,90.30,88.01,84.11,85.709,85.715,84.01,88.65/
        data sdsigs/5.87,24.56,10.06,5.36,9.02,16.51,3.22,8.22/
        data jyears/79,81,82,83,84,85,86,87/
	data nyears/8/
	
	basemort=0.03
        do i=1,20
        	xfish(i)=2.d0*slopes(i)
        end do 
         
c------- read in subitaneous clutch sizes
       open (unit=11,file='e:\diaptomus\demog\eggspc.pss',status='old')
       rewind(11)
       do i=1,180
           read(11,*) csiz(i)
       end do
       close(11)
       do i=181,400
           csiz(i)=csiz(180)
       end do
	
c---------------------------------------------------------------------
c    xma(ja) is a flag (1 or 0) for whether or not a clutch is produced
c----------------------------------------------------------------------
         do ja=1,41
                xma(ja)=0.d0
         end do
         xma(42)=1.d0
         do ja=43,110
             j1=ja-42
             if (mod(j1,7).eq.0) then
                xma(ja)=1.d0
             else
                xma(ja)=0.d0
             endif
         end do

c-------- compute v(ja), vulnerability to predation as function of age,
c-------- and xmub(ja), baseline mortality as a function of age
        call vulner(vstage,13)
        do ja=1,110
           js=jstage(ja)
           v(ja)=vstage(js)**0.83
        end do

        do jt=1,365
           xmub(jt)=basemu(jt)
        end do

C--------------- from here on things vary over time
	do jyr=1,nyears
	do kyr=1,nyears
		xmufish=xfish(jyr)
		cdate=cdates(jyr) 
		
		sdmean=sdmeans(kyr)
		sdsig=sdsigs(kyr) 

c-------- compute R0(jd), R0 as a function of birth date
        do jd=1,200
            rzero=0.
            xlafac=1.
            jdtau=jtau(jd)
            cbar=0.d0
            fc=0.d0
            do ja=1,110
               julday=jd+jdtau+ja
               xjulday=dble(julday) 
               clutsiz=0.62*csiz(julday)
C------------------- 0.62 because these are diapausing clutches
               bmu=xmub(julday)
               if (julday.lt.cdate) then
                  xmort=bmu
               else
                  xmort=bmu+v(ja)*xmufish
               endif
               pa(ja)=exp(-xmort)
               xlafac=xlafac*pa(ja)
               xla(ja)=xlafac
               rzero=rzero+xla(ja)*xma(ja)*clutsiz
               cbar=cbar+xla(ja)*xma(ja)*clutsiz
               fc=fc+xla(ja)*xma(ja)
            end do
            r0(jd)=rzero
            cmean(jd)=cbar/fc
        end do

c ----------- compute relative fitness W(jz) averaged over switch date
c ----------- distribution
       wbar=0.d0; 
       sfac1=1.d0/(sqrt(2.d0*pi)*sdsig) 
       sfac2=-1.d0/(2.d0*sdsig*sdsig)	
       do jz=20,180
           w=0.
           do jd=20,200
               fac1=pcfunc(jd)
               if (jd.lt.jz) then
                    fac2=0.5*r0(jd)*csiz(jd)
               else
                    fac2=0.62*csiz(jd)
               endif
               w=w+fac1*fac2
           end do
           pfac=sfac1*exp(sfac2*((dble(jz)-sdmean)**2)) 
           wbar=wbar+pfac*w
        end do
        write(*,86) jyr,kyr,wbar 

        end do 
        end do 
86	format(1x,2(1x,i3),f8.3) 
        stop
        end

C ----------------------------------------------------------------
C    Stage = stage as a function of age
C ----------------------------------------------------------------
        function jstage(ja)
        implicit real*8(a-h,o-z)
        js=12
        if (ja.le.37) js=11
        if (ja.le.34) js=10
        if (ja.le.31) js=9
        if (ja.le.28) js=8
        if (ja.le.25) js=7
        if (ja.le.21) js=6
        if (ja.le.18) js=5
        if (ja.le.15) js=4
        if (ja.le.9) js=3
        if (ja.le.4) js=2
        if (ja.le.2) js=1
        jstage=js
        return
        end

C ----------------------------------------------------------------
C   Vulner = vulnerability to predation as a function of stage
C ----------------------------------------------------------------
        subroutine vulner(v,ndimv)
        implicit real*8(a-h,o-z)
        dimension v(ndimv)
        v(1)=.001
        v(2)=.001
        v(3)=.003
        v(4)=.007
        v(5)=.015
        v(6)=.019

        v(7)=.026
        v(8)=.049
        v(9)=.10
        v(10)=.20
        v(11)=.43
        v(12)=1.135
        v(13)=1.27
        return
        end

C ----------------------------------------------------------------
C        basemu = baseline mortality rate as a function of date
C ----------------------------------------------------------------
        function basemu(jt)
        implicit real*8(a-h,o-z)
        parameter(pi=3.14159d0)
        common /params/ basemort
        xdate=2.*pi*dfloat(jt)/365.0
        temp=(7.5-5.8*cos(xdate)-2.0*sin(xdate))**(1.25)
        if (temp.le.10.0) then
              b=basemort
c        else if (temp.ge.20) then
c              b=0.094
        else
              b=basemort+0.1*(0.094-basemort)*(temp-10.0)
       end if
       basemu=b
       return
       end

C ----------------------------------------------------------------
C  pc(j)=fraction of cohort 1 clutches produced on Julian day j
C ----------------------------------------------------------------
        function pcfunc(j)
        implicit real*8(a-h,o-z)
        parameter(xmu=104.7,sig=20.9,pi=3.14159)
        dj=float(j)-xmu
        if (abs(dj).le.80.) then
          pc1=exp( -(dj**2)/(2.*sig*sig) )
          pc2=sqrt(2.*pi)*sig
          pc=pc1/pc2
        else
          pc=0.
        endif
        pcfunc=pc
        return
        end

C ----------------------------------------------------------------
C  tau(j)=development time for clutch layed on julian day j
C ----------------------------------------------------------------
        function jtau(j)
        implicit real*8(a-h,o-z)
        parameter(pi=3.14159,one=1.d0)
        sum=0.
        do i=j,100+j
            xdate=2.*pi*dfloat(i)/365.
            temp=(7.5-5.8*cos(xdate)-2.0*sin(xdate))**(1.25)
            rate=0.025+0.014*temp
            sum=sum+rate
            if (sum.lt.one) then
                jtemp=i+1
            endif
        end do
        jtau=jtemp-j
        return
        end
